/***************************************************************************
 *   Copyright (C) 2005 by Sergio Pistone                                  *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "transkodelogger.h"
#include <commondefs.h>

#include <qthread.h>
#include <qtextstream.h>
#include <qfileinfo.h>
#include <qfile.h>

TransKodeLogger::TransKodeLogger( const QString& path, const QString& prefix ):
	m_path( path ),
	m_file( m_path ),
	m_open( false ),
	m_prefix( prefix ),
	m_mutex( false )
{
	if ( m_path != "" && m_path != QString::null )
	{
		QFileInfo fileInfo( m_path );
		if ( !fileInfo.exists() || (fileInfo.exists() && fileInfo.isFile()) )
			m_open = m_file.open( IO_WriteOnly|IO_Append );
		else
			m_open = false;
	}
}


TransKodeLogger::~TransKodeLogger()
{
	m_mutex.lock();

	if ( m_open )
		m_file.close();

	m_mutex.unlock();
}

QString TransKodeLogger::file()
{
	m_mutex.lock();

	QString ret = String::deepCopy( m_path );

	m_mutex.unlock();

	return ret;
}

void TransKodeLogger::setFile( const QString& path )
{
	m_mutex.lock();

	if ( m_open )
		m_file.close();

	m_path = path;
	m_file.setName( m_path );

	if ( m_path != "" && m_path != QString::null )
	{
		QFileInfo fileInfo( m_path );
		if ( !fileInfo.exists() || (fileInfo.exists() && fileInfo.isFile()) )
			m_open = m_file.open( IO_WriteOnly|IO_Append );
		else
			m_open = false;
	}

	m_mutex.unlock();
}

void TransKodeLogger::setMsgPrefix( const QString& prefix )
{
	m_mutex.lock();

	m_prefix = prefix;

	m_mutex.unlock();
}

void TransKodeLogger::truncate()
{
	m_mutex.lock();

	if ( m_open )
	{
		m_file.close();
		m_open = m_file.open( IO_WriteOnly|IO_Truncate );
	}

	m_mutex.unlock();
}

void TransKodeLogger::log( const QString message )
{
	m_mutex.lock();

	if ( m_open )
	{
		QTextStream textStream( &m_file );
		textStream << m_prefix << message << "\n";
		m_file.flush();
	}

	m_mutex.unlock();
}
