#ifndef _TRANSKODECONFIG_H_
#define _TRANSKODECONFIG_H_

/***************************************************************************
 *   Copyright (C) 2005 by Sergio Pistone                                  *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <commondefs.h>
#include "profileoptions.h"

#include <qobject.h>
#include <qmutex.h>
#include <qstring.h>
#include <qstringlist.h>
#include <qvaluelist.h>
#include <qmap.h>

class TransKodeConfig : public QObject
{
	Q_OBJECT

	public:
		TransKodeConfig( const QString& defaultFile="" );
		TransKodeConfig( const TransKodeConfig& config );
		TransKodeConfig& operator=( const TransKodeConfig& config );

		QString defaultFile() const;
		void setDefaultFile( const QString& defaultFile );

		void loadDefaults();
		bool load( const QString& path );
		bool save( const QString& path ) const;

		bool encodeTypeIsSupported( EncodeType::TEncodeType encodeType ) const;
		QString supportedEncodingExtensions() const;
		bool programIsSupported( Program::TProgram program ) const;

		QString generalOpt( GeneralOpt::TGeneralOpt option ) const;
		QString programPath( Program::TProgram program, bool quoted=false ) const;
		CaseFunc::TCaseFunc tagCase( Tag::TTag tag ) const;
		QString tagDefault( Tag::TTag tag ) const;

		void setGeneralOpt( GeneralOpt::TGeneralOpt option, const QString& value );
		void setProgramPath( Program::TProgram program, const QString& value );
		void setTagCase( Tag::TTag tag, CaseFunc::TCaseFunc value );
		void setTagDefault( Tag::TTag tag, const QString& value );

		QStringList profiles() const;

		bool profileOptionsAreValid( const ProfileOptions* options ) const;
		bool profileIsValid( const QString& profile ) const;
		QStringList validProfiles() const;
		QStringList invalidProfiles() const;

		ProfileOptions* profileOptions( const QString& profile ) const;
		void setProfileOptions( const QString& profile, const ProfileOptions& opts );
		void removeProfile( const QString& profile );
		void clearProfiles();

	signals:
		void changed();

		void addedProfiles( const QStringList& profiles );
		void removedProfiles( const QStringList& profiles );
		void changedProfiles( const QStringList& profiles );

		void addedSuppEncodeTypes( const QValueList<int>& encodeTypes );
		void removedSuppEncodeTypes( const QValueList<int>& encodeTypes );

		void changedGeneralOpts( const QValueList<int>& options );
		void changedProgramPaths( const QValueList<int>& programs );
		void changedTagCases( const QValueList<int>& tags );
		void changedTagDefaults( const QValueList<int>& tags );

		void changedDefaultFile( const QString& prevDefaultFile );

	protected:

		void setGeneralOpt(
			GeneralOpt::TGeneralOpt option,
			const QString& value,
			bool& emitChanged,
			QValueList<int>& changedOptions,
			QStringList& changedProfiles );

		void setProgramPath(
			Program::TProgram program,
			const QString& value,
			bool& emitChanged,
			QValueList<int>& changedPaths,
			QValueList<int>& addedSuppEncTypes,
			QValueList<int>& removedSuppEncTypes );

		void setTagCase( Tag::TTag tag, CaseFunc::TCaseFunc value, bool& emitChanged, QValueList<int>& changedCases );

		void setTagDefault( Tag::TTag tag, const QString& value, bool& emitChanged, QValueList<int>& changedDefaults );

		void setProfileOptions(
			const QString& profile,
			const ProfileOptions& opts,
			bool& emitChanged,
			QStringList& addedProfiles,
			QStringList& changedProfiles );

		void removeProfile( const QString& profile, bool& emitChanged, QStringList& removedProfiles );

		void setDefaultFile( const QString& defFile, bool& emitChangedDefault, QString& prevDefaultFile );


		mutable QMutex m_configMutex;

		bool m_inited; // flag to indicate if signals should be emited on modification
		QString m_defaultFile; // file with default settings & profiles

		QString m_generalOptions[GeneralOpt::SIZE];
		CaseFunc::TCaseFunc m_tagCases[Tag::SIZE];
		QString m_tagDefaults[Tag::SIZE];
		QString m_programPaths[Program::SIZE];
		bool m_suppEncodeTypes[EncodeType::SIZE];
		QMap<QString,ProfileOptions> m_profiles;
};

#endif













