#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif
#include "speexencdialog.h"

#include <qregexp.h>
#include <qslider.h>
#include <qcheckbox.h>
#include <qspinbox.h>

void speexencDialog::fromEncodingSwitches( const QString& switches )
{
	QRegExp regExp;

	regExp.setPattern( "(^|[ \\t])--quality[ \\t]+([0-9]+)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
	{
		int quality = regExp.cap( 2 ).toInt();
		qualitySlider->setValue( quality>10 ? 8 : quality );
	}

	regExp.setPattern( "(^|[ \\t])--comp[ \\t]+([0-9]+)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
	{
		int complexity = regExp.cap( 2 ).toInt();
		complexitySlider->setValue( complexity > 10 ? 3 : complexity );
	}

	regExp.setPattern( "(^|[ \\t])(--vbr)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
		vbrCheckBox->setChecked( true );

	regExp.setPattern( "(^|[ \\t])(--vad)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
		vadCheckBox->setChecked( true );

	regExp.setPattern( "(^|[ \\t])(--dtx)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
		dtxCheckBox->setChecked( true );

	regExp.setPattern( "(^|[ \\t])(--denoise)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
		denoiseCheckBox->setChecked( true );

	regExp.setPattern( "(^|[ \\t])(--agc)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
		gainControlCheckBox->setChecked( true );

	regExp.setPattern( "(^|[ \\t])--nframes[ \\t]+([1-9]|10)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
	{
		framesPerPacketCheckBox->setChecked( true );
		framesPerPacketSpinBox->setValue( regExp.cap( 2 ).toInt() );
	}
}

QString speexencDialog::toEncodingSwitches()
{
	QString result;

	result = "--quality " + QString::number( qualitySlider->value() );
	result += " --comp " + QString::number( complexitySlider->value() );

	if ( vbrCheckBox->isChecked() )
		result += " --vbr";
	if ( vadCheckBox->isChecked() )
		result += " --vad";
	if ( dtxCheckBox->isChecked() )
		result += " --dtx";
	if ( denoiseCheckBox->isChecked() )
		result += " --denoise";
	if ( gainControlCheckBox->isChecked() )
		result += " --agc";
	if ( framesPerPacketCheckBox->isChecked() )
		result += " --nframes " + framesPerPacketSpinBox->cleanText();

	return result;
}
