#ifndef _TRANSKODEJOB_H_
#define _TRANSKODEJOB_H_

/***************************************************************************
 *   Copyright (C) 2005 by Sergio Pistone                                  *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <commondefs.h>
#include <transkodeconfig.h>

#include <kprocess.h>

class TransKodeWorker;

class TransKodeJob
{
	friend class TransKodeWorker;

	public:
		~TransKodeJob();

	protected:
		TransKodeJob(
			TransKodeWorker& worker,
			const QString& profile,
			const QString& srcURL );

		TransKodeJob(
			TransKodeWorker& worker,
			const QString& profile,
			const QString& srcURL,
			const QString& dstURL,
			const QString tags[Tag::SIZE] );

		int getID() const;

		void transcode();
		void cancel();
		bool wasCancelled() const;

		bool monitorProcess( KProcess& process );
		int ripStream( QStringList& paths );
		int decodeToWav( const QString& srcPath, const QString& dstPath );
		int encodeFromWav( const QString& srcPath, const QString& dstPath );

		QString generateDstPath(
			const QString& srcPath,
			const QString& dstExt,
			bool overwrite,
			bool vfat,
			const QString& replaceChars );

		QString resolveTagForFile( Tag::TTag tag, bool quote=false );
		QString resolveTagForPath( Tag::TTag tag, bool quote=false );

		void readTagsFromFile( const QString& filePath );
		void writeTagsToFile( const QString& filePath );

		static int getUnivocalID();
		static int s_idCount;
		static QMutex s_idCountMutex;

		const int m_jobID;

		TransKodeWorker& m_worker;

		mutable QMutex m_cancelledMutex;
		bool m_cancelled;

		QString m_profile;
		QString m_srcURL;
		QString m_dstURL;
		QString m_fileTags[Tag::SIZE];
		QString m_userTags[Tag::SIZE];
		ProfileOptions* m_profileOptions;
};

#endif
